//--------------------------------------------------------------
// File     : stm32_ub_i2c2.h
//--------------------------------------------------------------

//--------------------------------------------------------------
#ifndef __STM32F7_UB_I2C2_H
#define __STM32F7_UB_I2C2_H

//--------------------------------------------------------------
// Includes
//--------------------------------------------------------------
#include "stm32_ub_system.h"



//--------------------------------------------------------------
// MultiByte defines
//--------------------------------------------------------------
#define    I2C2_MULTIBYTE_ANZ   10         // anzahl der Bytes
uint8_t    I2C2_DATA[I2C2_MULTIBYTE_ANZ];  // Array



//--------------------------------------------------------------
// APB1-Clock = 50MHz
//--------------------------------------------------------------
#define I2C2_TIMING      0x40912732   // 100kHz



//--------------------------------------------------------------
// Defines
//-------------------------------------------------------------- 
#define   I2C2_TIMEOUT     1000       // Timeout Zeit in ms



//--------------------------------------------------------------
// I2C-GPIO-Pins
// moegliche Pinbelegung :
//   SCL : [PB10, PF1, PH4]
//   SDA : [PB11, PF0, PH5]
//--------------------------------------------------------------
#define  I2C2_SCL_PORT    GPIOF
#define  I2C2_SCL_PIN     GPIO_PIN_1

#define  I2C2_SDA_PORT    GPIOF
#define  I2C2_SDA_PIN     GPIO_PIN_0


//--------------------------------------------------------------
// Globale Funktionen
//--------------------------------------------------------------
void UB_I2C2_Init(void);
int16_t UB_I2C2_ReadByte(uint8_t slave_adr, uint8_t adr);
int16_t UB_I2C2_WriteByte(uint8_t slave_adr, uint8_t adr, uint8_t wert);
int16_t UB_I2C2_ReadMultiByte(uint8_t slave_adr, uint8_t adr, uint8_t cnt);
int16_t UB_I2C2_WriteMultiByte(uint8_t slave_adr, uint8_t adr, uint8_t cnt);
int16_t UB_I2C2_WriteCMD(uint8_t slave_adr, uint8_t cmd);
int16_t UB_I2C2_ReadByte16(uint8_t slave_adr, uint16_t adr);
int16_t UB_I2C2_WriteByte16(uint8_t slave_adr, uint16_t adr, uint8_t wert);
void UB_I2C2_Delay(volatile uint32_t nCount);




//--------------------------------------------------------------
#endif // __STM32F7_UB_I2C2_H
